Changelog
==========

from 0.3.7 to 0.3.7.1
---------------------

* quickfix for issue 21

from 0.3.6 to 0.3.7
-------------------

* fix documentation building
* temporary removal of the draco theme

from 0.3.5 to 0.3.6
--------------------

* kill bzr backend
* better checking for existing modules for backends
* fix bugs in MercurialRevision.isdir
* initial clone from remote support, still hackish
* use py.io.Terminalwriter for cli diff/status coloring
* support to iterate backends by featurs
